@@ -342,3 +342,109 @@ test_that("MuSSE_test2", {
     expect_true(comparison)
 })
 
+
+test_that("MuHiSSE_test1", {
+    skip_on_cran()
+
+    library(diversitree)
+    pars <- c(.1,  .15,  .2, .1, # lambda 1, 2, 3, 4
+    .03, .045, .06, 0.03, # mu 1, 2, 3, 4
+    .05, .05, .00,        # q12, q13, q14
+    .05, .00, .05,     # q21, q23, q24
+    .05, .00, .05,     # q31, q32, q34
+    .00, .05, .05)
+    set.seed(2)
+    phy <- tree.musse(pars, 30, x0=1)
+    states <- phy$tip.state
+    lik <- make.musse(phy, states, 4)
+    #lik <- make.musse(phy, states, 3)
+    diversitree.free = lik(pars)
+
+    states <- data.frame(phy$tip.state, phy$tip.state,
+    row.names=names(phy$tip.state))
+    states <- states[phy$tip.label,]
+    states.trans <- states
+    for(i in 1:Ntip(phy)){
+        if(states[i,1] == 1){
+            states.trans[i,1] = 0
+            states.trans[i,2] = 0
+        }
+        if(states[i,1] == 2){
+            states.trans[i,1] = 0
+            states.trans[i,2] = 1
+        }
+        if(states[i,1] == 3){
+            states.trans[i,1] = 1
+            states.trans[i,2] = 0
+        }
+        if(states[i,1] == 4){
+            states.trans[i,1] = 1
+            states.trans[i,2] = 1
+        }
+    }
+    pars.hisse <- c(pars[1]+pars[5],pars[2]+pars[6],pars[3]+pars[7],pars[4]+pars[8],pars[5]/pars[1],pars[6]/pars[2],pars[7]/pars[3],pars[8]/pars[4], 0.05,0.05,0, 0.05,0,0.05, 0.05,0,.05, 0,0.05,.05)
+    model.vec = rep(0,384)
+    model.vec[1:20] = pars.hisse
+    phy$node.label = NULL
+    cache <- hisse:::ParametersToPassMuHiSSE(model.vec=model.vec, hidden.states=TRUE,
+    nb.tip=Ntip(phy), nb.node=Nnode(phy),
+    bad.likelihood=exp(-500), ode.eps=0)
+    gen <- hisse:::FindGenerations(phy)
+    dat.tab <- hisse:::OrganizeData(states.trans, phy, f=c(1,1,1,1), hidden.states=TRUE)
+    hisse.constrained <- hisse:::DownPassMuHisse(dat.tab, gen=gen, cache=cache,
+    root.type="madfitz", condition.on.survival=TRUE)
+    comparison <- identical(round(hisse.constrained,4), round(diversitree.free,4))
+    expect_true(comparison)
+})
+
+
+test_that("MuHiSSE_test2", {
+    skip_on_cran()
+    
+    library(diversitree)
+    pars <- c(.1,  .15,  .2,  # lambda 1, 2, 3
+    .03, .045, .06, # mu 1, 2, 3
+    .05, 0,         # q12, q13
+    .05, .05,       # q21, q23
+    0,   .05)       # q31, q32
+    set.seed(2)
+    phy <- tree.musse(pars, 30, x0=1)
+    states <- phy$tip.state
+    lik <- make.musse(phy, states, 3)
+    lik.base <- constrain(lik, lambda2 ~ lambda1, lambda3 ~ lambda1,
+    mu2 ~ mu1, mu3 ~ mu1,
+    q13 ~ 0, q21 ~ q12, q23 ~ q12, q31 ~ 0.03, q32 ~ q12)
+    diversitree.constrained = lik.base(c(.1, .03, .05))
+
+    states <- data.frame(phy$tip.state, phy$tip.state, row.names=names(phy$tip.state))
+    states <- states[phy$tip.label,]
+    states[states[,1]==3,] = 4
+    states.trans <- states
+    for(i in 1:Ntip(phy)){
+        if(states[i,1] == 1){
+            states.trans[i,1] = 0
+            states.trans[i,2] = 0
+        }
+        if(states[i,1] == 2){
+            states.trans[i,1] = 0
+            states.trans[i,2] = 1
+        }
+        if(states[i,1] == 4){
+            states.trans[i,1] = 1
+            states.trans[i,2] = 0
+        }
+    }
+    pars.hisse <- c(0.1+0.03,0.1+0.03,0.1+0.03,0,0.03/0.1,0.03/0.1,0.03/0.1,0,0.05,0,0, 0.05,0.05,0, 0.03,0.05,0, 0,0,0)
+    model.vec = rep(0,384)
+    model.vec[1:20] = pars.hisse
+    phy$node.label = NULL
+    cache <- hisse:::ParametersToPassMuHiSSE(model.vec=model.vec, hidden.states=TRUE,
+    nb.tip=Ntip(phy), nb.node=Nnode(phy),
+    bad.likelihood=exp(-500), ode.eps=0)
+    gen <- hisse:::FindGenerations(phy)
+    dat.tab <- hisse:::OrganizeData(states.trans, phy, f=c(1,1,1,0), hidden.states=TRUE)
+    muhisse.constrained <- hisse:::DownPassMuHisse(dat.tab, gen=gen, cache=cache, root.type="madfitz", condition.on.survival=TRUE)
+    comparison <- identical(round(muhisse.constrained,4), round(diversitree.constrained,4))
+    expect_true(comparison)
+})
+
